@@ -9,19 +9,21 @@
 #define _mysql_version_h
 
 #define PROTOCOL_VERSION            10
-#define MYSQL_SERVER_VERSION       "5.7.44"
-#define MYSQL_BASE_VERSION         "mysqld-5.7"
+#define MYSQL_SERVER_VERSION       "8.0.36"
+#define MYSQL_BASE_VERSION         "mysqld-8.0"
 #define MYSQL_SERVER_SUFFIX_DEF    ""
-#define FRM_VER                     6
-#define MYSQL_VERSION_ID            50744
+#define MYSQL_VERSION_ID            80036
+#define MYSQL_VERSION_STABILITY     "LTS"
 #define MYSQL_PORT                  3306
+#define MYSQL_ADMIN_PORT            33062
 #define MYSQL_PORT_DEFAULT          0
 #define MYSQL_UNIX_ADDR            "/tmp/mysql.sock"
 #define MYSQL_CONFIG_NAME          "my"
+#define MYSQL_PERSIST_CONFIG_NAME  "mysqld-auto"
 #define MYSQL_COMPILATION_COMMENT  "Source distribution"
-#define LIBMYSQL_VERSION           "5.7.44"
-#define LIBMYSQL_VERSION_ID         50744
-#define SYS_SCHEMA_VERSION         "1.5.2"
+#define MYSQL_COMPILATION_COMMENT_SERVER  "Source distribution"
+#define LIBMYSQL_VERSION           "8.0.36"
+#define LIBMYSQL_VERSION_ID         80036
 
 #ifndef LICENSE
 #define LICENSE                     GPL
